==> haskell-transformers-compat-0.6.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.6.2
id: transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
key: transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
license: BSD-3-Clause
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
abi: 2861e904a53c8673e13fd14a2fc2b71f
exposed: True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal
hidden-modules: Paths_transformers_compat
import-dirs: /usr/lib/ghc-8.6.4/site-local/transformers-compat-0.6.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/transformers-compat-0.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/transformers-compat-0.6.2
hs-libraries: HStransformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
depends:
    base-4.12.0.0 ghc-prim-0.5.3 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-compat-0.6.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.6.3
id: transformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
key: transformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
license: BSD-3-Clause
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
abi: b3c40c2251ffef782c1c7e102b31f7a3
exposed: True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal
hidden-modules: Paths_transformers_compat
import-dirs: /usr/lib/ghc-8.6.4/site-local/transformers-compat-0.6.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/transformers-compat-0.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/transformers-compat-0.6.3
hs-libraries: HStransformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
depends:
    base-4.12.0.0 ghc-prim-0.5.3 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
